![django-logic-celery](https://user-images.githubusercontent.com/6745569/87846587-7e57f580-c903-11ea-8ef7-b3ca129c92b1.png)

[![Build Status](https://travis-ci.org/Borderless360/django-logic-celery.svg?branch=master)](https://travis-ci.org/Borderless360/django-logic-celery)[![Coverage Status](https://coveralls.io/repos/github/Borderless360/django-logic-celery/badge.svg?branch=master)](https://coveralls.io/github/Borderless360/django-logic-celery?branch=master)

The main idea of [Django Logic](https://github.com/Borderless360/django-logic) is to allow developers implementing 
business logic via pure functions. Django-Logic-Celery takes care of the connection
between the pure functions and the business requirements, based on a state of the model object.
Please, make sure to make yourself familiar with [Django Logic](https://github.com/Borderless360/django-logic) first,
as it implements the core functionality and the very package is the only extension allowing using Celery tasks. 


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install Django-Logic-Celery.

```bash
pip install django-logic-celery
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)

## Project status
Under development
